#
# spec file for package sevctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sevctl
Version:        0.6.0
Release:        1.4
Summary:        Administrative utility for AMD SEV
Group:          Development/Libraries/Rust
License:        Apache-2.0
URL:            https://github.com/virtee/sevctl
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  libopenssl-devel
BuildRequires:  rubygem(asciidoctor)
ExclusiveArch:  x86_64

%description
Administrative utility for AMD SEV

%files
%doc README.md
%{_bindir}/sevctl

%prep
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%changelog
* Wed Oct 23 2024 caleb.crane@suse.com
- Update to version 0.6.0:
  * Update to 0.6.0
  * session: Use anyhow macro for error return
  * Update sev crate to 4.0.0
  * secret: Use From::from conversion
  * Add Cargo.lock
  * show: Patching bug from clap migration
  * build(deps): update reqwest requirement from 0.11.18 to 0.12.4
  * build(deps): update bitfield requirement from 0.14.0 to 0.15.0
* Thu Oct  3 2024 Caleb Crane <caleb.crane@suse.com>
- Spec: Add direct dependency on cargo in addition to cargo-packaging.
    This fixes build errors on 15SP7 where the inherited version of Rust
    is too old
- Service: Remove deprecated cargo_config and cargo_audit services, both
    are now handled by the cargo_vendor service
* Wed Jan 24 2024 Caleb Crane <caleb.crane@suse.com>
- Fix CVE-2023-50711: vmm-sys-util: out of bounds memory accesses (bsc#1218502, bsc#1218499)
  - Upgrade vendored dependencies, namely vmm-sys-utils > 0.12.0
- spec: Switch back to greedy cargo updates of vendored dependencies. This CVE was multiple
  levels deep in the dependency tree and only fixed with the more agressive cargo update strategy
* Wed Sep 13 2023 Caleb Crane <caleb.crane@suse.com>
- Update to sevctl v0.4.3 (jsc#4981)
  - Add show commands for identifier and VCEK URL
  - Improve processor identification
  - Add 'sevctl measurement build'
  - Expand coverage for all AMD CPU model numbers
  - Adjust to use sev VMSA result changes
  - Add vmsa show command
  - Implement vmsa update subcommand
  - Implement vmsa build subcommand
  - Detect and use host arch's CPU generation
  - Support HTTP/HTTPS proxies
- Spec: Upgrade vendored dependencies
- Spec: Utilize upstream git tags
* Wed Apr 19 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire rubygem(asciidoctor) instead of %%{rubygem
  asciidoctor}" the %%rubygem} macro expands to all ruby versions,
  wheras we are perfectly fine with getting only one version for
  asciidoctor into the buildroot.
* Tue Mar 14 2023 Caleb Crane <caleb.crane@suse.com>
- Update to v0.3.2 + git commit 255d370
    dependency: Enable vendored feature for openssl
    Add show commands for identifier, SNP status and VCEK URL.
    readme: Add some basic provisioning instructions
    Update sev library to version 1.1.0
    ok: Find singular model and family on processor ID
* Wed Feb  8 2023 Caleb Crane <caleb.crane@suse.com>
- Set cargo_vendor update param to false to bypass upstream semvar issues
* Tue Jan 31 2023 James Fehlig <jfehlig@suse.com>
- Update to v0.3.2 + git commit e37c4d6
    src/main: Remove README portion of main.rs
    .github: Remove cargo readme CI test
    docs: Add a generable man page
    ci: Add asciidoctor as a build dependency
    ok: Add Genoa processor identifying
    ok: Rewrite processor generation querying
    secret: Add docs and update README.md
    Add `secret build` subcommand
    measurement: rework some functions for use with `secret build`
    main: Improve error printing on exit
    measurement: Add docs and update README.md
    measurement: Comment why we aren't using sev crate
    Change `measurement build` output to measurement+nonce
    Add `measurement build --launch-measure-blob`
    Add `measurement build --vmsa-cpu0, --vmsa-cpu1, --num-cpus`
    Add `measurement build --firmware --kernel --initrd --cmdline`
    Add `measurement build --outfile PATH`
    Let `measurement build --tk` accept path or base64 string
    Let `measurement build` accept int values as hex too
    Add `measurement build` subcommand
    Update version to 0.3.2
    Update sev crate to 1.0.1
    Update to 0.3.1
    Update to 0.3.1
    build(deps): bump httparse from 1.7.1 to 1.8.0
    Add CODEOWNERS file
    CI: Drop rust 1.51.0 testing
    Fix clippy warnings with rust nightly
    ok: Show if Page flush MSR is enabled/disabled
    ok: Change TestResult.name to String
    Replace error.rs with anyhow crate
    ok: Expand coverage for all AMD CPU model numbers
* Thu Jul  7 2022 Caleb Crane <caleb.crane@suse.com>
- Disable obs_scm service by default
- Use a commit hash as the checked out revision corresponding to crate version 0.3.0
- Change version format to be clear we are using a git commit hash
* Thu Jul  7 2022 Caleb Crane <caleb.crane@suse.com>
- Build for x86_64 only
* Thu Jul  7 2022 Caleb Crane <caleb.crane@suse.com>
- Initial package for sevctl v0.3.0 (https://github.com/virtee/sevctl)
- FIXME: Upstream has no tags so using HEAD revision
